#!/usr/bin/perl
# greenflag2mapsonus.pl

# This script converts routes generated by www.greenflag.com to a format 
# similar to the RAW output of www.mapsonus.com.  The intention of this script
# is entirely to allow the parsing program included in the Empeg application
# gpsapp (which was written specificly for the output of mapsonus) to work for
# directions made by greenflag.  The result is a route with turn waypoints, but
# no additional route shape points.  Until greenflag includes more waypoints, 
# this is all of the waypoint information available.

# To generate a route containing all of the information that is needed by this 
# script, make sure the Directions Style format is set to 'Step By Step Maps'
# The other options shouldn't matter, but if in doubt, use the defaults.

# This was written based on the HTML generated as of Febuary 16, 2003.  Any 
# changes made in the output of the directions from greenflag may cause
# this script to no longer generate correct output.  If this script doesn't 
# work, look for a more current version or learn Perl and change it yourself.

# Copyright 2003 by Colin Verne

# Usage greenflag2mapsonus.pl <input file>

if ($#ARGV != 0)
{
	print "Usage: $0 <input file>\n";
	exit
}

unless (open(FILE, "<$ARGV[0]"))
{
	print "Could not open $ARGV[0] for reading.";
	exit;
}

my @lines = <FILE>;
my $turn = 0;
my $in_turn = 0;
my @route_points;

foreach $line (@lines)
{
	# try to match the lines containing maps of the turn points.
	if ($line =~ /^.*?MakeMap\.d\?S=938&amp;CT=.*?%3A-.*?%3A.*?&amp;H=100&amp;IC=(.*?)3%3A-(.*?)%3A100%3A.*?%3A(.*?)3%3A-(.*?)%3A100%3A.*?%3A.*?$/)
	{
		$lat = $1;
		$lon = $2;
		$last_lat = $3;
		$last_lon = $4;
		$in_turn = 1;
		next;
	}
	#if in a turn, look for the turn description
	elsif ($in_turn && $line =~ /^.*?<font color=\"\#00542C\" size\=\"2\"\>(.*?)<\/font>.*?$/)
	{
		$desc = $1;
		
		# extract just the road
		if ($desc =~ /^.*?on <b>(.*?)<\/b>.*?$/)
		{
			$desc = $1;
		}
		else
		{
			#otherwise don't include the direction
			$desc = '';
		}
		
		# remove formatting tags
		#$dir =~ s/<.*?>//g;
		
		if ($turn == 0)
		{
			print "START $lon $lat {MARK.START} Start Point\n";
		}
		
		print "TURN $turn $lon $lat $turn 1 0 0 0 0.0 $desc\n";
		push(@route_points, "$lon $lat");
		$in_turn = 0;
		$turn++;
	}
}

print "END $last_lon $last_lat {MARK.END} End Point\nMIN 0\n".join('  ', @route_points);
